@@ -5,6 +5,11 @@ pycraigslist.query
 A suite of modules that interface with the Craigslist API.
 """
 
-from pycraigslist.query.filters import parse, get_addl_filters, get_addl_filters_readable
+from pycraigslist.query.filters import (
+    parse_filters,
+    get_addl_filters,
+    get_addl_filters_readable,
+    validate_region,
+)
 from pycraigslist.query.search import fetch_posts, get_total_post_count
 from pycraigslist.query.search_detail import fetch_detailed_posts
